==========================
Plover Mod-Z
==========================

This plugin for plover provides the *Plover Mod-Z* system which is a minor modification of the standard English steno layout.
The only change is that the top S- is replaced with Z-.

The motivation was to bring the English layout closer to the German Regenpfeifer layout.

Since Z- is not present in the usual English layout, there are no conflicts with existing English dictionaries.

Installation
------------

To install the cloned git repository, you can run the following command:

Windows

.. code:: powershell

	.\plover_console.exe -s plover_plugins install <path-to-git-repo>

Mac

.. code:: bash

	/Applications/Plover.app/Contents/MacOS/Plover -s plover_plugins install <path-to-git-repo>

Packaging
------------

To package the plugin, run:

.. code:: bash

              python3 -m build

And to upload to PyPi, run:

.. code:: bash

              twine upload dist/*

See also the instructions on [python.org](https://packaging.python.org/en/latest/tutorials/packaging-projects/).

Special Thanks
--------------

Special thanks to Benoit Pierre, Ted Morin, and Nicholas Markopoulos for providing source code and valuable hints on how to set up the plugin.

License
-------

This plugin is licensed under GPLv3, or any later version.
